#!/usr/bin/env python
#
# Enumerate usb devices
#
#Copyright 2005 - 2007 Wander Lairson Costa

import usb

busses = usb.busses()

for bus in busses:
	devices = bus.devices
	for dev in devices:
		print "Device:", dev.filename
		print "  Device class:",dev.deviceClass
		print "  Device sub class:",dev.deviceSubClass
		print "  Device protocol:",dev.deviceProtocol
		print "  Max packet size:",dev.maxPacketSize
		print "  idVendor: %d (0x%04x)" % (dev.idVendor, dev.idVendor)
		print "  idProduct: %d (0x%04x)" % (dev.idProduct, dev.idProduct)
		print "  Device Version:",dev.deviceVersion
		for config in dev.configurations:
			print "  Configuration:", config.value
			print "    Total length:", config.totalLength 
			print "    selfPowered:", config.selfPowered
			print "    remoteWakeup:", config.remoteWakeup
			print "    maxPower:", config.maxPower
			for intf in config.interfaces:
				print "    Interface:",intf[0].interfaceNumber
				for alt in intf:
					print "    Alternate Setting:",alt.alternateSetting
					print "      Interface class:",alt.interfaceClass
					print "      Interface sub class:",alt.interfaceSubClass
					print "      Interface protocol:",alt.interfaceProtocol
					for ep in alt.endpoints:
						print "      Endpoint:",hex(ep.address)
						print "        Type:",ep.type
						print "        Max packet size:",ep.maxPacketSize
						print "        Interval:",ep.interval




#!/usr/bin/env python

"""
Provides an interface to USB Printer Class devices.
"""

import usb
import types

PRINTER_CLASS			= 0x07
PRINTER_SUBCLASS		= 0x01
UNIDIRECTIONAL_PROTOCOL	= 0x01
BIDIRECTIONAL_PROTOCOL	= 0x02
IEEE1284_4_PROTOCOL		= 0x03
VENDOR_PROTOCOL			= 0xff

class Printer:
	def __init__(self, device, configuration, interface):
		"""
		__init__(device, configuration, interface) -> None

		Initialize the device.
			device: printer usb.Device object.
			configuration: printer usb.Configuration object of the Device or configuration number.
			interface: printer usb.Interface object representing the
			           interface and altenate setting.
			
		"""
		if PRINTER_CLASS != interface.interfaceClass:
			raise TypeError, "Wrong interface class"

		self.__devhandle = device.open()
		self.__devhandle.setConfiguration(configuration)
		self.__devhandle.claimInterface(interface)
		self.__devhandle.setAltInterface(interface)

		self.__intf = interface.interfaceNumber
		self.__alt	= interface.alternateSetting

		self.__conf = (type(configuration) == types.IntType \
						or type(configuration) == types.LongType) and \
						configuration or \
						configuration.value

		# initialize members
		# TODO: automatic endpoints detection
		self.__bulkout	= 1
		self.__bulkin	= 0x82
	
	def __del__(self):
		try:
			self.__devhandle.releaseInterface(self.__intf)
			del self.__devhandle
		except:
			pass

	def getDeviceID(self, maxlen, timeout = 100):
		"""
		getDeviceID(maxlen, timeout = 100) -> device_id

		Get the device capabilities information.
			maxlen: maxlength of the buffer.
			timeout: operation timeout.
		"""
		return self.__devhandle.controlMsg(requestType = 0xa1,
										   request = 0,
										   value = self.__conf - 1,
										   index = self.__alt + (self.__intf << 8),
										   buffer = maxlen,
										   timeout = timeout)
	
	def getPortStatus(self, timeout = 100):
		"""
		getPortStatus(timeout = 100) -> status

		Get the port status.
			timeout: operation timeout.
		"""
		return self.__devhandle.controlMsg(requestType = 0xa1,
										   request = 1,
										   value = 0,
										   index = self.__intf,
										   buffer = 1,
										   timeout = timeout)[0]

	def softReset(self, timeout = 100):
		"""
		softReset(timeout = 100) -> None

		Request flushes all buffers and resets the Bulk OUT
		and Bulk IN pipes to their default states.
			timeout: the operation timeout.
		"""
		self.__devhandle.controlMsg(requestType = 0x21,
								   	request = 2,
								   	value = 0,
								   	index = self.__intf,
								   	buffer = 0)

	
	def write(self, buffer, timeout = 100):
		"""
		write(buffer, timeout = 100) -> written

		Write data to printer.
			buffer: data buffer.
			timeout: operation timeout.
		"""
		return self.__devhandle.bulkWrite(self.__bulkout,
										  buffer,
										  timeout)

	def read(self, numbytes, timeout = 100):
		"""
		read(numbytes, timeout = 100) -> data

		Read data from printer.
			numbytes: number of bytes to read.
			timeout: operation timeout.
		"""
		return self.__devhandle.bulkRead(self.__bulkin,
										 numbytes,
										 timeout)





#!/usr/bin/env python
#
# PyUSB setup script
#
# Copyright 2005 - 2010 Wander Lairson Costa

from distutils.core import setup, Extension
import sys
import os
from os.path import join

program_files = os.getenv('PROGRAMFILES')

extra_link_args = []
extra_compile_args = []
platform = sys.platform.lower()
libraries = ["usb"]

# necessary to work fine in MacOS
# many thanks to Damian Staniforth! :-)
if -1 != platform.find("mac"):
    extra_link_args = ['-framework',
                       'CoreFoundation',
                       '-framework',
                       'IOKit']
elif -1 != platform.find("win32"):
    libraries = ["libusb"]
    extra_link_args = ['/LIBPATH:' + join(program_files, 'Libusb-win32', 'lib', 'msvc')]
    extra_compile_args = ['/I' + join(program_files, 'Libusb-win32', 'include')]
# necessary to work fine in darwin
# Many thanks to James Barabas!
elif -1 != platform.find("darwin"):
    extra_link_args = ['-framework',
                       'CoreFoundation',
                       '-framework',
                       'IOKit',
                       '-L/sw/lib',
                       '-L/usr/local/lib']
    extra_compile_args = ['-I/sw/include','-I/usr/local/lib', '-l/opt/local/lib']
# Juha Torkkel has reported problems compiling on freebsd
# when libusb is in /usr/local tree. I don't know on freebsd, but
# on Linux the paths to usr/local are in $PATH.
# Thanks Juha... ;)
elif -1 != platform.find("freebsd"):
    extra_link_args = ['-L/usr/local/lib']
    extra_compile_args = ['-I/usr/local/include']
# Added by Xiaofan Chen for NetBSD
# Tested under NetBSD 4.0 and Python 2.4
elif -1 != platform.find("netbsd"):
    extra_link_args = ['-L/usr/pkg/lib']
    extra_compile_args = ['-I/usr/pkg/include']                                                                                                         

usbmodule = Extension(name = 'usb',
                    libraries = libraries,
                    sources = ['pyusb.c'],
                    extra_link_args = extra_link_args,
                    extra_compile_args = extra_compile_args,
                    depends = ['pyusb.h'])

setup(name = 'pyusb',
    version = '0.4.3',
    description = "USB access extension module",
    long_description =
    """
    PyUSB provides easy USB access to python.
    The module contains classes and methods to
    support the most USB operations.
    """,
    author = 'Wander Lairson Costa',
    author_email = 'wander.lairson@gmail.com',
    url = 'http://pyusb.sourceforge.net',
    license = 'BSD',
    ext_modules = [usbmodule])

# vim:ts=4
